"""Calculate the packet overhead to send the given arguments in SNAP Connect"""
try:
    import snaplib.SnapConstantsHelper as sch
except ImportError:
    # This moved in newer versions of SNAP Connect
    # Try both locations to support both
    import snappy.SnapConstantsHelper as sch

import snaplib.RpcCodec


def get_dmcast_packet_overhead(func, *args):
    """Return the max packet overhead of the given args for a dmcast packet.

    Right now, we just append 3 integers representing  Group, TTL, and Delay
    """
    calc_args = (0, 0, 0) + args  # Account for Group, TTL, and Delay
    return get_packet_overhead(func, *calc_args)


def get_packet_overhead(func, *args):
    """Return the max packet overhead of the given args"""
    saved_append_crc = snaplib.RpcCodec.appendCrc
    saved_packet_size = sch.MAX_PKT_SIZE

    snaplib.RpcCodec.appendCrc = True
    sch.MAX_PKT_SIZE -= 2

    desc = snaplib.RpcCodec.RpcDescriptor()  # Create a packet
    desc.isMulticast = True
    # Set all of the values
    desc.srcAddr = "\x00\x00\x01"
    desc.dstAddr = '\x00\x01'  # this is mcast group for multicasts
    desc.ttl = 1
    desc.funcName = func
    desc.args = args
    rpc_string = snaplib.RpcCodec.RpcCodec.encode(desc)
    length = len(rpc_string)
    snaplib.RpcCodec.appendCrc = saved_append_crc
    sch.MAX_PKT_SIZE = saved_packet_size
    return length


def get_max_addrs(overhead):
    """Return the maximum number of target addresses that will fit in a packet

    :param int overhead: The overhead of the packet
    """
    return ((sch.MAX_PKT_SIZE - 2) - overhead) / 3
